@@ -1,11 +1,12 @@
 from seekout.objects.product import Product
 from seekout.parsers.generic import ProductSearchPage
+from seekout.parsers.utils import parse_price
 
 
-def parse_product(soup):
+def parse_newegg_product(soup):
     title = soup.find("a", {"class": "item-title"}).text
     url = soup.find("a", {"class": "item-title"})["href"]
-    price = soup.find("li", {"class": "price-current"}).text
+    price = parse_price(soup.find("li", {"class": "price-current"}).text)
     if price:
         in_stock = True
     else:
@@ -34,9 +35,18 @@ def parse_product(soup):
 
 
 class NeweggSearch(ProductSearchPage):
+    base_url = "https://www.newegg.com"
+    categories = {"gpu": "100007709"}
+
+    @staticmethod
+    def search_url(self, text, category):
+        parsed_text = text.replace(" ", "+").lower()
+        category_id = self.categories.get(category)
+        return f"{self.base_url}/p/pl?d={parsed_text}&N={category_id}"
+
     def _parse_page(self):
         raw_products = self._get_products()
-        products = list(map(parse_product, raw_products))
+        products = list(map(parse_newegg_product, raw_products))
         self.products += products
 
     def _get_products(self):
